AudioConfig

Struct AudioConfig 

#[non_exhaustive]
pub struct AudioConfig { pub audio_encoding: AudioEncoding, pub speaking_rate: f64, pub pitch: f64, pub volume_gain_db: f64, pub sample_rate_hertz: i32, pub effects_profile_id: Vec<String>, /* private fields */ }
Description of audio data to be synthesized.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
audio_encoding: AudioEncoding

Required. The format of the audio byte stream.

speaking_rate: f64

Optional. Input only. Speaking rate/speed, in the range [0.25, 2.0]. 1.0 is the normal native speed supported by the specific voice. 2.0 is twice as fast, and 0.5 is half as fast. If unset(0.0), defaults to the native 1.0 speed. Any other values < 0.25 or > 2.0 will return an error.

pitch: f64

Optional. Input only. Speaking pitch, in the range [-20.0, 20.0]. 20 means increase 20 semitones from the original pitch. -20 means decrease 20 semitones from the original pitch.

volume_gain_db: f64

Optional. Input only. Volume gain (in dB) of the normal native volume supported by the specific voice, in the range [-96.0, 16.0]. If unset, or set to a value of 0.0 (dB), will play at normal native signal amplitude. A value of -6.0 (dB) will play at approximately half the amplitude of the normal native signal amplitude. A value of +6.0 (dB) will play at approximately twice the amplitude of the normal native signal amplitude. Strongly recommend not to exceed +10 (dB) as there’s usually no effective increase in loudness for any value greater than that.

sample_rate_hertz: i32

Optional. The synthesis sample rate (in hertz) for this audio. When this is specified in SynthesizeSpeechRequest, if this is different from the voice’s natural sample rate, then the synthesizer will honor this request by converting to the desired sample rate (which might result in worse audio quality), unless the specified sample rate is not supported for the encoding chosen, in which case it will fail the request and return [google.rpc.Code.INVALID_ARGUMENT][google.rpc.Code.INVALID_ARGUMENT].

effects_profile_id: Vec<String>

Optional. Input only. An identifier which selects ‘audio effects’ profiles that are applied on (post synthesized) text to speech. Effects are applied on top of each other in the order they are given. See audio profiles for current supported profile ids.

Implementations

Source

impl AudioConfig

pub fn new() -> Self

Creates a new default instance.

pub fn set_audio_encoding<T: Into<AudioEncoding>>(self, v: T) -> Self

Sets the value of audio_encoding.

Example
use google_cloud_texttospeech_v1::model::AudioEncoding;
let x0 = AudioConfig::new().set_audio_encoding(AudioEncoding::Linear16);
let x1 = AudioConfig::new().set_audio_encoding(AudioEncoding::Mp3);
let x2 = AudioConfig::new().set_audio_encoding(AudioEncoding::OggOpus);
pub fn set_speaking_rate<T: Into<f64>>(self, v: T) -> Self

Sets the value of speaking_rate.

Example
let x = AudioConfig::new().set_speaking_rate(42.0);
pub fn set_pitch<T: Into<f64>>(self, v: T) -> Self

Sets the value of pitch.

Example
let x = AudioConfig::new().set_pitch(42.0);
pub fn set_volume_gain_db<T: Into<f64>>(self, v: T) -> Self

Sets the value of volume_gain_db.

Example
let x = AudioConfig::new().set_volume_gain_db(42.0);
pub fn set_sample_rate_hertz<T: Into<i32>>(self, v: T) -> Self

Sets the value of sample_rate_hertz.

Example
let x = AudioConfig::new().set_sample_rate_hertz(42);
pub fn set_effects_profile_id<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of effects_profile_id.

Example
let x = AudioConfig::new().set_effects_profile_id(["a", "b", "c"]);